#!/bin/sh
#    Make the Diva API documentation in the current directory:
# makeJar <javahome> <divaroot> <jarfile> ?<packages>...?
# Version: $Id: makeJar.sh,v 1.2 2002/01/12 18:51:06 johnr Exp $

# This is a shell script instead of a tclsh script so that it will
# work more easily under Windows with Cygwin, which might not have Tcl
# installed

#
# Get arguments
if [ $# -lt 5 ]; then
    echo "makeJar <javahome> <divaroot> <jarfile> ?<packages>...?"
    exit 4
fi
javahome=$1
divaroot=$2
jarfile=$3
shift;shift;shift

jartmpdir=$divaroot/jartmpdir
mkdir $jartmpdir

divaparent=`dirname $divaroot`
dp=`pwd`
echo
echo
echo "**** Building JAR file: $dp/diva.jar ****"
echo
echo

for pkg in $*
do
    echo "Copying .class files for $pkg"
    dir=`echo "$pkg" | sed 's/\./\//g'`
    if [ ! -d "$dir" ]; then
	echo "Warning: '$dir' does not exist"
    fi 
    tar -cf - $divaparent/$dir/*.class | (cd $jartmpdir; tar -xf -)

    echo "Copying misc file list for $pkg"
    localmiscfiles="`cd $dir; make echo_MISC_FILES | 
	grep -v 'Leaving directory' | grep -v 'Entering directory' |
	awk '{for (i=1;i<=NF;i++) {
		print dir "/" $i
	      }  
	    }' dir=${dir} `"
    #echo "localmiscfiles = $localmiscfiles"
    if [ "$localmiscfiles" != "" ]; then
	tar -cf - $localmiscfiles | (cd $jartmpdir; tar -xf -)	    
    fi	
done

echo "Creating $jarfile from $jartmpdir"
$javahome/bin/jar cf $jarfile  -C $jartmpdir .

echo "Removing $jartmpdir"
rm -rf $jartmpdir

echo
echo
echo "**** Diva JAR file built in $dp/diva.jar ****"
echo
echo
