# buildAPI.tcl: build Diva APIs
#
# $Id: buildAPI.tcl,v 1.10 2001/07/22 21:47:09 johnr Exp $
#
# Copyright (c) 1998-2001 The Regents of the University of California.
# All rights reserved. See the file COPYRIGHT for details.
#


### Assumed global variables:
# debug: print debug information if on
# silent: don't print anything if on
# DIVA: the root of the Diva tree


#######################################################################
#### buildAPI
#
# Given a list of package names, build the API in the current directory.
# The arguments are the packages that are included in the generated
# docs.
#
proc buildAPI {DIVA args} {
    global debug silent

    if $debug {
	puts "Building API for $args"
    }

    # Need to reparse makefile to get classpath right...
    clearMakevars
    cd [file join $DIVA doc api]
    parseMakefile makefile

    set docflags [getMakevar JAVADOC_FLAGS]
    set javahome [getMakevar JAVAHOME]
    set classpath [getMakevar CLASSPATH]

    # Filter and process packages
    set packages {}
    foreach p $args {
	# Check the directory
	set dir [eval file join $DIVA [lreplace [split $p .] 0 0]]
	if ![file exists $dir] {
	    error "Package directory \"$dir\" does not exist"
	} elseif { [glob -nocomplain [file join $dir *.java]] == "" } {
	    if !$silent {
		puts "$p -- empty -- ignoring"
	    }
	} else {
	    if !$silent {
		puts "$p -- ok"
	    }
	    lappend packages $p
	}
    }

    set cmd "[file join $javahome bin javadoc] \
	-classpath $classpath \
	$docflags \
	$packages"

    if !$silent {
	puts "$cmd"
    }
    catch {eval exec $cmd} result
    if !$silent {
	puts $result
    }

    ### FIXME FIXME Stupid bug in JDK1.2beta4 for Solaris
    #exec sed "s/#FFFFF /#FFFFFF /" stylesheet.css > tmpfile
    #file delete stylesheet.css
    #file rename tmpfile stylesheet.css
}







